@@ -5,6 +5,7 @@ from ai_butler_sdk.utils import unzip_file
 from ai_butler_sdk.apis.client import update_train_task_status, TrainStatusEnum
 from loguru import logger
 import shutil
+import traceback
 
 
 class TrainBase:
@@ -119,8 +120,8 @@ class TrainBase:
             self.train()
             self.after_train()
             self.upload_result()
-        except Exception as e:
-            logger.error(f"训练任务失败: {e}")
+        except Exception:
+            logger.error(f"训练任务失败: {traceback.format_exc()}")
             update_train_task_status(self.train_task_id, TrainStatusEnum.FAILURE)
         else:
             update_train_task_status(self.train_task_id, TrainStatusEnum.FINISH)
